#
# spec file for package qqc2-desktop-style
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _tar_path 5.45
Name:           qqc2-desktop-style
Version:        5.45.0
Release:        lp150.1.1
Summary:        A Qt Quick Controls 2 Style for Desktop UIs
License:        GPL-2.0-or-later
Group:          Development/Libraries/KDE
Url:            http://www.kde.org/
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/qqc2-desktop-style-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch:          fix-build-with-gcc48.patch
BuildRequires:  extra-cmake-modules >= 0.0.8
BuildRequires:  kf5-filesystem
# For dir ownership
BuildRequires:  kconfigwidgets-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kirigami2-devel
BuildRequires:  cmake(Qt5Core) >= 5.9.1
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
# For KUA users
Provides:       plasma5-qqc2-style = %{version}
Obsoletes:      plasma5-qqc2-style < %{version}
Requires:       libqt5-qtquickcontrols2
# plasma5-workspace sets up the env variables so that this theme
# is picked by default. It still works fine without it (no requires),
# but looks better with it. By itself plasma5-workspace does not use
# it (yet), so only install it with libqt5-qtquickcontrols2.
Supplements:    packageand(plasma5-workspace:libqt5-qtquickcontrols2)

%description
A Qt Quick Controls 2 style engine that uses the desktop style
to draw controls with QStyle.

%package devel
Summary:        Development Files for Qt Quick Controls 2 Desktop Style
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules

%description devel
This file contains cmake files to be used by projects that depend on
qqc2-desktop-style.
Usually not needed as it is only a runtime dependency.

%prep
%setup -q
%if 0%{?suse_version} < 1500
%patch -p1
%endif

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build

%files
%doc LICENSE*
%{_kf5_qmldir}/QtQuick/Controls.2/org.kde.desktop/
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%dir %{_kf5_plugindir}/kf5/kirigami/
%{_kf5_plugindir}/kf5/kirigami/org.kde.desktop.so
%{_kf5_qmldir}/org/kde/qqc2desktopstyle/

%files devel
%{_kf5_libdir}/cmake/KF5QQC2DeskopStyle/

%changelog
* Mon Apr 16 2018 wbauer@tmo.at
- Add fix-build-with-gcc48.patch to make it compile with gcc 4.8 on
  Leap 42.3
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * fix rendering when disabled
  * better layout
  * experimental support for auto mnemonics
  * We depend against 5.8.0
  * Make sure we are taking into account hte size of the element when styling
  * Fix font rendering for non-HiDPI and integer scale factors (kde#391780)
  * e our way to handle shortcuts
  * fix icons colors with colorsets
  * fix icon colors for toolbuttons
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Fix syntax error in previous commit, detected by launching ruqola
  * Show a radiobutton when we are showing an exclusive control
  * fix some Qt 5.9 bugs
  * implement MenuBarItem
  * fix logic
  * implement DelayButton
  * New component: round button
  * take into account toolbar position
  * support colors for icons in buttons
  * support --reverse
  * icons in Menu fully functional
  * consistent shadows with the new breeze style
  * ame behavior as qwidget menus
  * make icons actually work
  * Some QStyles seem to not return sensible pixelmetrics here
  * first rough icons support
  * don't wrap around with mouse wheel
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * use the inactive or disabled color group when needed
  * Apply some C++11 niceties, styling consistency
  * Add BusyIndicator to the styled controls list
  * remove flicker when hovering scrollbar
  * Cache KColorScheme instances
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * simplify and don't try to block mouse events
  * if no wheel.pixelDelta, use global wheel scroll lines
  * desktop tabbars have different widths for each tab
  * ensure a non 0 size hint
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * determine QQC2 version at build time (kde#386289)
  * by default, keep the background invisible
  * add a background in ScrollView
* Tue Nov 14 2017 wbauer@tmo.at
- Fix QtQuickControls2 BuildRequires, it needs the devel package to
  build
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Improve compilation as a static plugin.
  * make the radiobutton a radiobutton
  * use qstyle to paint the Dial
  * use a ColumnLayout for menus
  * fix Dialog
  * remove invalid group property
  * Add .arcconfig
  * Fix formatting of the md file so it matches the other modules
  * behavior of combobox closer to qqc1
  * workaround for QQuickWidgets
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Too many to list here
* Sat Aug 19 2017 fabian@ritter-vogt.de
- Initial packaging
